gnunet-svn
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

[gnunet-scheme] 92/324: guix: Add guile-quickcheck dependency.


From: gnunet
Subject: [gnunet-scheme] 92/324: guix: Add guile-quickcheck dependency.
Date: Tue, 21 Sep 2021 13:22:12 +0200

This is an automated email from the git hooks/post-receive script.

maxime-devos pushed a commit to branch master
in repository gnunet-scheme.

commit cbf44acd3dc5c8cd9a4b6c868dbd435ea29fa874
Author: Maxime Devos <maximedevos@telenet.be>
AuthorDate: Wed Mar 17 12:32:12 2021 +0100

    guix: Add guile-quickcheck dependency.
    
    This will be used for testing.
    
    * guix.scm
      (guile-quickcheck): Define guile-quickcheck.
      (scheme-gnunet)[native-inputs]: Add guile-quickcheck.
---
 guix.scm | 68 ++++++++++++++++++++++++++++++++++++++++++++++++----------------
 1 file changed, 51 insertions(+), 17 deletions(-)

diff --git a/guix.scm b/guix.scm
index a79f41a..c9291cf 100644
--- a/guix.scm
+++ b/guix.scm
@@ -1,20 +1,24 @@
 ;;   This file is part of scheme-GNUnet, a partial Scheme port of GNUnet.
 ;;   Copyright (C) 2021 Maxime Devos <maximedevos@telenet.be>
 ;;
 ;;   GNUnet is free software: you can redistribute it and/or modify it
 ;;   under the terms of the GNU Affero General Public License as published
 ;;   by the Free Software Foundation, either version 3 of the License,
 ;;   or (at your option) any later version.
 ;;
 ;;   GNUnet is distributed in the hope that it will be useful, but
 ;;   WITHOUT ANY WARRANTY; without even the implied warranty of
 ;;   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 ;;   Affero General Public License for more details.
 ;;
 ;;   You should have received a copy of the GNU Affero General Public License
 ;;   along with this program.  If not, see <http://www.gnu.org/licenses/>.
 ;;
 ;;   SPDX-License-Identifier: AGPL-3.0-or-later
 
 (use-modules (gnu packages guile)
             (gnu packages guile-xyz)
@@ -22,9 +26,37 @@
             (gnu packages gettext)
             (gnu packages pkg-config)
             (guix packages)
+            (guix download)
             (guix build-system gnu)
             ((guix licenses) #:prefix license:))
 
+(define-public guile-quickcheck
+  (package
+    (name "guile-quickcheck")
+    (version "0.1.0")
+    (source (origin
+              (method url-fetch)
+              (uri (string-append "https://files.ngyro.com/";
+                                  "guile-quickcheck/guile-quickcheck-"
+                                  version ".tar.gz"))
+              (sha256
+               (base32
+                "03mwi1l3354x52nar0zwhcm0x29yai9xjln4p4gbchwvx5dsr6fb"))))
+    (build-system gnu-build-system)
+    (native-inputs
+     `(("pkg-config" ,pkg-config)
+       ("guile" ,guile-3.0)))
+    (inputs
+     `(("guile" ,guile-3.0)))
+    (home-page "https://ngyro.com/software/guile-quickcheck.html";)
+    (synopsis "Randomized property-based testing for Guile")
+    (description "This Guile library provides tools for randomized,
+property-based testing.  It follows closely the QuickCheck library
+written in Haskell.  You can use it to define a property (a predicate
+with specifications for its inputs) and test it by generating many
+random inputs and seeing if it holds.")
+    (license license:gpl3+)))
+
 (define-public scheme-gnunet
   (package
    (name "scheme-gnunet")
@@ -37,6 +69,8 @@
                        ("guile-json" ,guile-json-4)))
    (native-inputs `(("guile" ,guile-3.0)
                    ("automake" ,automake)
+                   ;; Only used for testing.
+                   ("guile-quickcheck" ,guile-quickcheck)
                     ;; Gettext brings 'AC_LIB_LINKFLAGS_FROM_LIBS'.
                    ("gettext" ,gettext-minimal)
                    ("pkg-config" ,pkg-config)
@@ -1,20 +1,24 @@
-;;   This file is part of scheme-GNUnet, a partial Scheme port of GNUnet.
-;;   Copyright (C) 2021 Maxime Devos <maximedevos@telenet.be>
-;;
-;;   GNUnet is free software: you can redistribute it and/or modify it
-;;   under the terms of the GNU Affero General Public License as published
-;;   by the Free Software Foundation, either version 3 of the License,
-;;   or (at your option) any later version.
-;;
-;;   GNUnet is distributed in the hope that it will be useful, but
-;;   WITHOUT ANY WARRANTY; without even the implied warranty of
-;;   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-;;   Affero General Public License for more details.
-;;
-;;   You should have received a copy of the GNU Affero General Public License
-;;   along with this program.  If not, see <http://www.gnu.org/licenses/>.
-;;
-;;   SPDX-License-Identifier: AGPL-3.0-or-later
+;;; GNU Guix --- Functional package management for GNU
+;;; Copyright © 2021 Maxime Devos <maximedevos@telenet.be>
+;;; Copyright © 2021 Timothy Sample <samplet@ngyro.com>
+;;;   ^ definition of guile-quickcheck
+;;;
+;;; This file is part of GNU Guix.
+;;;
+;;; GNU Guix is free software; you can redistribute it and/or modify it
+;;; under the terms of the GNU General Public License as published by
+;;; the Free Software Foundation; either version 3 of the License, or (at
+;;; your option) any later version.
+;;;
+;;; GNU Guix is distributed in the hope that it will be useful, but
+;;; WITHOUT ANY WARRANTY; without even the implied warranty of
+;;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+;;; GNU General Public License for more details.
+;;;
+;;; You should have received a copy of the GNU General Public License
+;;; along with GNU Guix.  If not, see <http://www.gnu.org/licenses/>.
+;;;
+;;;  SPDX-License-Identifier: GPL-3.0-or-later
 
 (use-modules (gnu packages guile)

-- 
To stop receiving notification emails like this one, please contact
gnunet@gnunet.org.



reply via email to

[Prev in Thread] Current Thread [Next in Thread]